==> reference4-1.0-sources.jar: one/xingyi/reference4/person/client/view/PersonNameView.java <==
package one.xingyi.reference4.person.client.view;
//Made by one.xingyi.core.filemaker.ClientViewInterfaceFileMaker
//Defn one.xingyi.reference4.person.IPersonNameViewDefn
import one.xingyi.core.sdk.IXingYiView;
import one.xingyi.core.annotations.XingYiGenerated;
import java.util.function.Function;
import one.xingyi.core.http.ServiceRequest;
import one.xingyi.core.http.ServiceResponse;
import one.xingyi.core.utils.IdAndValue;
import java.util.Optional;
import one.xingyi.core.optics.Lens;
import java.util.concurrent.CompletableFuture;
import one.xingyi.core.httpClient.HttpServiceCompletableFuture;
import one.xingyi.core.httpClient.client.view.UrlPattern;
import java.lang.String;
public interface PersonNameView  extends IXingYiView<one.xingyi.reference4.person.client.entitydefn.IPersonClientEntity>{
    public static <T> CompletableFuture<T> get(HttpServiceCompletableFuture service, String id, Function<one.xingyi.reference4.person.client.view.PersonNameView, T> fn){return service.get(one.xingyi.reference4.person.client.viewcompanion.PersonNameViewCompanion.companion,id,fn);}
    public static <T> CompletableFuture<Optional<T>> getOptional(HttpServiceCompletableFuture service, String id, Function<one.xingyi.reference4.person.client.view.PersonNameView, T> fn){return service.getOptional(one.xingyi.reference4.person.client.viewcompanion.PersonNameViewCompanion.companion,id,fn);}
    public static CompletableFuture<one.xingyi.reference4.person.client.view.PersonNameView > edit(HttpServiceCompletableFuture service, String id, Function<one.xingyi.reference4.person.client.view.PersonNameView,one.xingyi.reference4.person.client.view.PersonNameView> fn){return service.edit(one.xingyi.reference4.person.client.viewcompanion.PersonNameViewCompanion.companion,id, fn);}
    public static CompletableFuture<one.xingyi.reference4.person.client.view.PersonNameView> create(HttpServiceCompletableFuture service, String id){return service.create(one.xingyi.reference4.person.client.viewcompanion.PersonNameViewCompanion.companion,id);}
    public static CompletableFuture<IdAndValue<one.xingyi.reference4.person.client.view.PersonNameView>> create(HttpServiceCompletableFuture service, one.xingyi.reference4.person.client.view.PersonNameView view){return service.createWithoutId(one.xingyi.reference4.person.client.viewcompanion.PersonNameViewCompanion.companion, view);}
    public static CompletableFuture<Boolean> delete(HttpServiceCompletableFuture service, String id){return service.delete(one.xingyi.reference4.person.client.viewcompanion.PersonNameViewCompanion.companion,id);}
    //ViewFieldDom(typeDom=PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String)), name=name, readOnly=false, lensName=lens for views not done yet, lensPath=lens path for views not done yet, javascript=function lens for views not done yet(){return lens('name');};, templated=false, deprecated=false)
    //EntityOptional[FieldDom(typeDom=PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String)), name=name, readOnly=true, lensName=lens_Person_name, lensPath=name/String, javascript=function lens_Person_name(){return lens('name');};, templated=false, deprecated=false)]
    default public Lens<PersonNameView,java.lang.String> nameLens(){ return xingYi().stringLens(one.xingyi.reference4.person.client.viewcompanion.PersonNameViewCompanion.companion, "lens_Person_name");}
    default public java.lang.String name(){ return nameLens().get(this);};
}

==> reference4-1.1-sources.jar: one/xingyi/reference4/person/client/view/PersonNameView.java <==
package one.xingyi.reference4.person.client.view;
//Made by one.xingyi.core.filemaker.ClientViewInterfaceFileMaker
//Defn one.xingyi.reference4.person.IPersonNameViewDefn
import one.xingyi.core.sdk.IXingYiView;
import one.xingyi.core.annotations.XingYiGenerated;
import java.util.function.Function;
import one.xingyi.core.http.ServiceRequest;
import one.xingyi.core.http.ServiceResponse;
import one.xingyi.core.utils.IdAndValue;
import java.util.Optional;
import one.xingyi.core.optics.Lens;
import java.util.concurrent.CompletableFuture;
import one.xingyi.core.httpClient.HttpServiceCompletableFuture;
import one.xingyi.core.httpClient.client.view.UrlPattern;
import java.lang.String;
public interface PersonNameView  extends IXingYiView<one.xingyi.reference4.person.client.entitydefn.IPersonClientEntity>{
    public static <T> CompletableFuture<T> get(HttpServiceCompletableFuture service, String id, Function<one.xingyi.reference4.person.client.view.PersonNameView, T> fn){return service.get(one.xingyi.reference4.person.client.viewcompanion.PersonNameViewCompanion.companion,id,fn);}
    public static <T> CompletableFuture<Optional<T>> getOptional(HttpServiceCompletableFuture service, String id, Function<one.xingyi.reference4.person.client.view.PersonNameView, T> fn){return service.getOptional(one.xingyi.reference4.person.client.viewcompanion.PersonNameViewCompanion.companion,id,fn);}
    public static CompletableFuture<one.xingyi.reference4.person.client.view.PersonNameView > edit(HttpServiceCompletableFuture service, String id, Function<one.xingyi.reference4.person.client.view.PersonNameView,one.xingyi.reference4.person.client.view.PersonNameView> fn){return service.edit(one.xingyi.reference4.person.client.viewcompanion.PersonNameViewCompanion.companion,id, fn);}
    public static CompletableFuture<one.xingyi.reference4.person.client.view.PersonNameView> create(HttpServiceCompletableFuture service, String id){return service.create(one.xingyi.reference4.person.client.viewcompanion.PersonNameViewCompanion.companion,id);}
    public static CompletableFuture<IdAndValue<one.xingyi.reference4.person.client.view.PersonNameView>> create(HttpServiceCompletableFuture service, one.xingyi.reference4.person.client.view.PersonNameView view){return service.createWithoutId(one.xingyi.reference4.person.client.viewcompanion.PersonNameViewCompanion.companion, view);}
    public static CompletableFuture<Boolean> delete(HttpServiceCompletableFuture service, String id){return service.delete(one.xingyi.reference4.person.client.viewcompanion.PersonNameViewCompanion.companion,id);}
    //ViewFieldDom(typeDom=StringPrimitiveType(), name=name, readOnly=false, lensName=lens for views not done yet, lensPath=lens path for views not done yet, javascript=function lens for views not done yet(){return lens('name');};, templated=false, deprecated=false)
    //EntityOptional[FieldDom(typeDom=StringPrimitiveType(), name=name, readOnly=true, lensName=lens_Person_name, lensPath=name/String, javascript=function lens_Person_name(){return lens('name');};, templated=false, deprecated=false)]
    default public Lens<PersonNameView,java.lang.String> nameLens(){ return xingYi().stringLens(one.xingyi.reference4.person.client.viewcompanion.PersonNameViewCompanion.companion, "lens_Person_name");}
    default public java.lang.String name(){ return nameLens().get(this);};
}
